summaryrefslogtreecommitdiff
path: root/src/Models/LogEntry.php
diff options
context:
space:
mode:
authorIgor Scheller <igor.scheller@igorshp.de>2019-07-28 19:13:05 +0200
committerIgor Scheller <igor.scheller@igorshp.de>2019-07-29 00:58:06 +0200
commit5d3efb625477f4412d0360244737a7524e7f5149 (patch)
tree56045c046587806ac9b9a7a8707a4597463746d4 /src/Models/LogEntry.php
parent219c54411bb765bebd7813ad3e49ab05acf0b150 (diff)
Models: Updated method and property hints
Diffstat (limited to 'src/Models/LogEntry.php')
-rw-r--r--src/Models/LogEntry.php18
1 files changed, 10 insertions, 8 deletions
diff --git a/src/Models/LogEntry.php b/src/Models/LogEntry.php
index db427eb9..8eb62ac9 100644
--- a/src/Models/LogEntry.php
+++ b/src/Models/LogEntry.php
@@ -2,19 +2,21 @@
namespace Engelsystem\Models;
+use Carbon\Carbon;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Collection;
+use Illuminate\Database\Query\Builder as QueryBuilder;
/**
- * @property int $id
- * @property string $level
- * @property string $message
- * @property \Carbon\Carbon|null $created_at
+ * @property int $id
+ * @property string $level
+ * @property string $message
+ * @property Carbon|null $created_at
*
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereId($value)
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereLevel($value)
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereMessage($value)
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereCreatedAt($value)
*/
class LogEntry extends BaseModel
{
@@ -2,19 +2,21 @@
*
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereId($value)
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereLevel($value)
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereMessage($value)
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\LogEntry[] whereCreatedAt($value)
+ * @method static QueryBuilder|LogEntry whereId($value)
+ * @method static QueryBuilder|Collection|LogEntry[] whereLevel($value)
+ * @method static QueryBuilder|Collection|LogEntry[] whereMessage($value)
+ * @method static QueryBuilder|Collection|LogEntry[] whereCreatedAt($value)
*/
class LogEntry extends BaseModel